;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "fwb-cmds" "20251101.2015"
  "Misc frame, window and buffer commands."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/fwb-cmds"
  :commit "2c36c716a5cf86e790ad1acbd2a062230c78eec2"
  :revdesc "2c36c716a5cf"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.fwb-cmds@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.fwb-cmds@jonas.bernoulli.dev")))
